﻿//An InDesign CS2 JavaScript
//
//Name:		trimMarks.jsx [based on CropMarks.jsx]
//Version:	1.02
//Date  :	23.09.2005
//Author:	Vlad Ossipov
//E-mail:	pp.ossipov@inbox.ru
//
//Description:
//Draws trim marks around the selected object or objects.
//Данный скрипт написан на основе скрипта CropMarks.jsx
//поставляющегося с пакетом Creative Suite 2.
//	
//	Изменения по сравнению с оригиналом (CropMarks.jsx):
//	+ исключена возможность установки меток приводки (reg marks)	
//	+ добавлен выбор цвета меток (по умолчанию Black)
//	+ добавлен параметр Bleed (отступ на подрезку)
//
//
//For more on InDesign scripting, go to http://www.adobe.com/products/indesign/scripting.html
//or visit the InDesign Scripting User to User forum at http://www.adobeforums.com

//@include 'trimMarks.ini';
//@include 'trimMarks.ru.slang';

if (app.documents.length != 0){
	if (app.selection.length > 0){
		switch(app.selection[0].constructor.name){
			case "Rectangle":
			case "Oval":
			case "Polygon":
			case "GraphicLine":
			case "Group":
			case "TextFrame":
			case "Button":
				myDisplayDialog();
				break;
			default:			
				alert("Please select a page item and try again.");
				break;
		}
	}
	else{
		alert("Please select an object and try again.");
	}
}
else{
	alert("Please open a document, select an object, and try again.");
}
function myDisplayDialog(){
	var myDialog = app.dialogs.add({name:iniScriptName+" "+iniScriptVersion+" by Vlad Ossipov"});
	var mySwatchNameList = new Array;
	for(var mySwatchCounter = 0; mySwatchCounter < app.activeDocument.swatches.length; mySwatchCounter++){
		mySwatch = app.activeDocument.swatches.item(mySwatchCounter);
		if(mySwatch.name != "Registration"){
			mySwatchNameList.push(mySwatch.name);
		}
	}
	with(myDialog){
		with(dialogColumns.add()){
				with(borderPanels.add()){
					staticTexts.add({staticLabel:langOptions});
					with (dialogColumns.add()){
						staticTexts.add({staticLabel:langLength});
						staticTexts.add({staticLabel:langOffset});
						staticTexts.add({staticLabel:langBleed});
						staticTexts.add({staticLabel:langMarksWeight});
						staticTexts.add({staticLabel:langMarksColor});
					}
					with (dialogColumns.add()){
						var myCropMarkLengthField = measurementEditboxes.add({editValue:defaultLength, editUnits:MeasurementUnits.millimeters});
						var myCropMarkOffsetField = measurementEditboxes.add({editValue:defaultOffset, editUnits:MeasurementUnits.millimeters});
						var myCropMarkBleedField = measurementEditboxes.add({editValue:defaultBleed, editUnits:MeasurementUnits.millimeters});
						var myCropMarkWidthField = measurementEditboxes.add({editValue:defaultStrokeWeight, editUnits:MeasurementUnits.points});
						var myFillColorDropdown = dropdowns.add({stringList:mySwatchNameList, selectedIndex:2});
					}
				}
			with(borderPanels.add()){
				staticTexts.add({staticLabel:langMarksAround});
				var myRangeButtons = radiobuttonGroups.add();
				with(myRangeButtons){
					radiobuttonControls.add({staticLabel:langEach, checkedState:true});
					radiobuttonControls.add({staticLabel:langEntire});
				}
			}
		}
	}
	var myReturn = myDialog.show();
	if (myReturn == true){
		//Get the values from the dialog box.
		var myRegistrationColor = myFillColorDropdown.stringList[myFillColorDropdown.selectedIndex];
		var myCropMarkLength = myCropMarkLengthField.editValue;
		var myCropMarkOffset = myCropMarkOffsetField.editValue;
		var myCropMarkWidth = myCropMarkWidthField.editValue;
		var myCropMarkBleed = myCropMarkBleedField.editValue;
		var myRange = myRangeButtons.selectedButton;
		myDialog.destroy();
		myDrawPrintersMarks(myRegistrationColor, myRange, myCropMarkLength, myCropMarkOffset, myCropMarkBleed, myCropMarkWidth);
	}
	else{
		myDialog.destroy();
	}
}
function myDrawPrintersMarks(myRegistrationColor, myRange, myCropMarkLength, myCropMarkOffset, myCropMarkBleed, myCropMarkWidth){
	var myBounds, myX1, myY1, myX2, myY2, myObject;
	var myDocument = app.activeDocument;
	var myOldRulerOrigin = myDocument.viewPreferences.rulerOrigin;
	myDocument.viewPreferences.rulerOrigin = RulerOrigin.spreadOrigin;
	//Save the current measurement units.
	var myOldXUnits = myDocument.viewPreferences.horizontalMeasurementUnits;
	var myOldYUnits = myDocument.viewPreferences.verticalMeasurementUnits;
	//Set the measurement units to points.
	myDocument.viewPreferences.horizontalMeasurementUnits = MeasurementUnits.points;
	myDocument.viewPreferences.verticalMeasurementUnits = MeasurementUnits.points;
	//Create a layer to hold the printers marks (if it does not already exist).
	var myLayer = myDocument.layers.item("trimMarks");
	try{
		myLayerName = myLayer.name;
	}
	catch (myError){
		var myLayer = myDocument.layers.add({name:"trimMarks"});
	}
	myLayer.move(LocationOptions.atEnd);
	//Get references to the Registration color and the None swatch.
	var myNoneSwatch = myDocument.swatches.item("None");
	//Process the objects in the selection.		
	myBounds = myDocument.selection[0].visibleBounds;
	for(var myCounter = 0; myCounter < myDocument.selection.length; myCounter ++){
		myObject = myDocument.selection[myCounter];
		myBounds = myObject.visibleBounds;
		//Set up some initial bounding box values.
		if ((myRange != 0)&&(myCounter==0)){
			myX1 = myBounds[1];
			myY1 = myBounds[0];
			myX2 = myBounds[3];
			myY2 = myBounds[2];
		}
		if(myRange == 0){		
			myDrawCropMarks (myBounds[1] , myBounds[0], myBounds[3], myBounds[2], myCropMarkLength, myCropMarkOffset, myCropMarkBleed, myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
		}
		else{
			//Compare the bounds values to the stored bounds.
			//If a given bounds value is less than (for x1 and y1) or 
			//greater than (for x2 and y2) the stored value,
			//then replace the stored value with the bounds value.
			if (myBounds[0] < myY1){
				myY1 = myBounds[0];
			}
			if (myBounds[1] < myX1){
				myX1 = myBounds[1];
			}
			if (myBounds[2] > myY2){
				myY2 = myBounds[2];
			}
			if (myBounds[3] > myX2){
				myX2 = myBounds[3];
			}
		}
	}
	if(myRange != 0){
		myDrawCropMarks (myX1, myY1, myX2, myY2, myCropMarkLength, myCropMarkOffset, myCropMarkBleed, myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
	}
	myDocument.viewPreferences.rulerOrigin = myOldRulerOrigin;
	//Set the measurement units back to their original state.
	myDocument.viewPreferences.horizontalMeasurementUnits = myOldXUnits;
	myDocument.viewPreferences.verticalMeasurementUnits = myOldYUnits;
}
function myDrawCropMarks (myX1, myY1, myX2, myY2, myCropMarkLength, myCropMarkOffset, myCropMarkBleed, myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer){

	//Upper left crop mark pair.
	myDrawLine([myY1+myCropMarkBleed, myX1-myCropMarkOffset, myY1+myCropMarkBleed, myX1-(myCropMarkOffset + myCropMarkLength)], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
	myDrawLine([myY1-myCropMarkOffset, myX1+myCropMarkBleed, myY1-(myCropMarkOffset+myCropMarkLength), myX1+myCropMarkBleed], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);

	//Lower left crop mark pair.
	myDrawLine([myY2-myCropMarkBleed, myX1-myCropMarkOffset, myY2-myCropMarkBleed, myX1-(myCropMarkOffset+myCropMarkLength)], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
	myDrawLine([myY2+myCropMarkOffset, myX1+myCropMarkBleed, myY2+myCropMarkOffset+myCropMarkLength, myX1+myCropMarkBleed], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);

	//Upper right crop mark pair.
	myDrawLine([myY1+myCropMarkBleed, myX2+myCropMarkOffset, myY1+myCropMarkBleed, myX2+myCropMarkOffset+myCropMarkLength], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
	myDrawLine([myY1-myCropMarkOffset, myX2-myCropMarkBleed, myY1-(myCropMarkOffset+myCropMarkLength), myX2-myCropMarkBleed], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);

	//Lower left crop mark pair.
	myDrawLine([myY2-myCropMarkBleed, myX2+myCropMarkOffset, myY2-myCropMarkBleed, myX2+myCropMarkOffset+myCropMarkLength], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
	myDrawLine([myY2+myCropMarkOffset, myX2-myCropMarkBleed, myY2+myCropMarkOffset+myCropMarkLength, myX2-myCropMarkBleed], myCropMarkWidth, myRegistrationColor, myNoneSwatch, myLayer);
}

function myDrawLine(myBounds, myStrokeWeight, myRegistrationColor, myNoneSwatch, myLayer){
	app.activeWindow.activeSpread.graphicLines.add(myLayer, undefined, undefined,{strokeWeight:myStrokeWeight, fillColor:myNoneSwatch, strokeColor:myRegistrationColor, geometricBounds:myBounds})
}

//This function removes the menu entry "Random," and also removes
//the swatches "Registration" and "None" from the list of available
//swatch names (because we don't want those applied to the objects).
function myCleanSwatchNames(mySwatchNameList){
	//Remove "Random"
	mySwatchNameList.pop();
	for(myCounter = 0; myCounter < mySwatchNameList.length; myCounter ++){
		mySwatchName = mySwatchNameList.shift();
		//If the swatch name is not one of the "bad" names, then write it back to the end of the list.
		if((mySwatchName!="None")&&(mySwatchName!="Registration")){
			mySwatchNameList.push(mySwatchName);
		}
	}
	return mySwatchNameList;
}